==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/elevator1/dialogs_en.lua <==

dialogId("zd1-v-civil", "font_big", "What a glorious civilization. So many centuries under water and their elevators still work.")

dialogId("zd1-m-tlac", "font_small", "Especially, when we push them.")

dialogId("zd1-m-dolu", "font_small", "But only down.")

dialogId("zd1-m-last", "font_small", "Do you see that shell?")

dialogId("zd1-v-talis", "font_big", "It`s an age-old talisman for elevator builders who always said 'Build well. Build with Shell`.")

dialogId("zd1-m-poved", "font_small", "Isn`t that shell a little bit familiar?")

dialogId("zd1-v-styd", "font_big", "They should be ashamed of themselves. This is subliminal advertising.")

dialogId("zd1-v-lebka", "font_big", "That skull looks familiar.")

dialogId("zd1-m-stejne", "font_small", "All human skulls look the same... Unlike fish skeletons.")

dialogId("zd1-m-cesta", "font_small", "This is a tough path.")

dialogId("zd1-v-krecek", "font_big", "I feel like a mouse on a treadmill.")

dialogId("zd1-m-slap", "font_small", "A treadmill for fish? But we only have fins.")

dialogId("zd1-x-huhu1", "font_lightgrey", "Hoo, hooooo, hoooo... I`m over heeeere...")

dialogId("zd1-x-huhu2", "font_lightgrey", "Hoooo, if you want I`ll tell you how to solve all the levels...")

dialogId("zd1-x-huhu3", "font_lightgrey", "Hooo, ho, hooo, I know why the city sank!")

dialogId("zd1-x-huhu4", "font_lightgrey", "Hoooo, why isn`t anyone paying attention to me?")

dialogId("zd1-x-huhu5", "font_lightgrey", "Hoooo ho hooo! Why are you ignoring me?")

dialogId("zd1-x-huhu6", "font_lightgrey", "Hooooo, hooooo, fish! Pay attention to me!")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/elevator1/dialogs_en.lua <==

dialogId("zd1-v-civil", "font_big", "What a glorious civilization. So many centuries under water and their elevators still work.")

dialogId("zd1-m-tlac", "font_small", "Especially, when we push them.")

dialogId("zd1-m-dolu", "font_small", "But only down.")

dialogId("zd1-m-last", "font_small", "Do you see that shell?")

dialogId("zd1-v-talis", "font_big", "It’s an age-old talisman for elevator builders who always said 'Build well. Build with Shell’.")

dialogId("zd1-m-poved", "font_small", "Isn’t that shell a little bit familiar?")

dialogId("zd1-v-styd", "font_big", "They should be ashamed of themselves. This is subliminal advertising.")

dialogId("zd1-v-lebka", "font_big", "That skull looks familiar.")

dialogId("zd1-m-stejne", "font_small", "All human skulls look the same... Unlike fish skeletons.")

dialogId("zd1-m-cesta", "font_small", "This is a tough path.")

dialogId("zd1-v-krecek", "font_big", "I feel like a mouse on a treadmill.")

dialogId("zd1-m-slap", "font_small", "A treadmill for fish? But we only have fins.")

dialogId("zd1-x-huhu1", "font_lightgrey", "Hoo, hooooo, hoooo... I’m over heeeere...")

dialogId("zd1-x-huhu2", "font_lightgrey", "Hoooo, if you want I’ll tell you how to solve all the levels...")

dialogId("zd1-x-huhu3", "font_lightgrey", "Hooo, ho, hooo, I know why the city sank!")

dialogId("zd1-x-huhu4", "font_lightgrey", "Hoooo, why isn’t anyone paying attention to me?")

dialogId("zd1-x-huhu5", "font_lightgrey", "Hoooo ho hooo! Why are you ignoring me?")

dialogId("zd1-x-huhu6", "font_lightgrey", "Hooooo, hooooo, fish! Pay attention to me!")
